@@ -49,7 +49,7 @@ class provider():
 	def sendSMS(self, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
 		return False, "SMS sending not implemented"
 
-# o2online.de 2.4
+# o2online.de 2.5
 # o2online (DE) Provider written by Bjoern Olausson <maemo@olausson.de>
 class provider_o2online_de(provider):
 	def getName(self):
@@ -290,11 +290,19 @@ class provider_o2online_de(provider):
 			# Open the EMAIL-Center
 			#------------------------------------
 			UpdatePbar(self, MainWindow, app, "5", "Step 5: Open EmailCenter")
+			#------------------------------------
+			# Check for a redirect
+			#------------------------------------
+			for link in br.links(text_regex="SMS"):
+				print link
+			if re.search("weitergeleitet", response):
+				return error(self, MainWindow, 'Redirection failed', 'Step 5: Redirection failed, please try again')
+
 			try:
-				br.find_link(text='Mail[IMG]E-Mail')
-			except mechanize.LinkNotFoundError:
-				return error(self, MainWindow, e, 'Step 5: Link "E-Mail" nicht gefunden')
-			req = br.click_link(text='Mail[IMG]E-Mail')
+				br.find_link(text_regex="Mail")
+			except mechanize.LinkNotFoundError, e:
+				return error(self, MainWindow, e, 'Step 5: Link "E-Mail" not found, please try again')
+			req = br.click_link(text_regex="Mail")
 			try:
 				br.open(req)
 				response = br.response().read()
